==> applet-service-2.0.0-20200619.085014-9-sources.jar: com/bizvane/appletservice/models/bo/CouponDetailResponseBo.java <==
package com.bizvane.appletservice.models.bo;

import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.Date;

public class CouponDetailResponseBo {
    @ApiModelProperty(
            value = "pkid",
            name = "couponEntityId",
            required = false,
            example = ""
    )
    private Long couponEntityId;
    @ApiModelProperty(
            value = "所属企业id",
            name = "sysCompanyId",
            required = false,
            example = ""
    )
    private Long sysCompanyId;
    @ApiModelProperty(
            value = "所属品牌id",
            name = "sysBrandId",
            required = false,
            example = ""
    )
    private Long sysBrandId;
    @ApiModelProperty(
            value = "所属品牌编号",
            name = "brandCode",
            required = false,
            example = ""
    )
    private String brandCode;
    @ApiModelProperty(
            value = "券号",
            name = "couponCode",
            required = false,
            example = ""
    )
    private String couponCode;
    @ApiModelProperty(
            value = "券定义id",
            name = "couponDefinitionId",
            required = false,
            example = ""
    )
    private String couponDefinitionId;
    @ApiModelProperty(
            value = "券发送记录id",
            name = "couponBatchSendRecordId",
            required = false,
            example = ""
    )
    private Long couponBatchSendRecordId;
    @ApiModelProperty(
            value = "会员code",
            name = "memberCode",
            required = false,
            example = ""
    )
    private String memberCode;
    @ApiModelProperty(
            value = "券名称",
            name = "couponName",
            required = false,
            example = ""
    )
    private String couponName;
    @ApiModelProperty(
            value = "面额",
            name = "money",
            required = false,
            example = ""
    )
    private BigDecimal money;
    @ApiModelProperty(
            value = "折扣",
            name = "discount",
            required = false,
            example = ""
    )
    private BigDecimal discount;
    @ApiModelProperty(
            value = "券模板图片",
            name = "img",
            required = false,
            example = ""
    )
    private String img;
    @ApiModelProperty(
            value = "券说明",
            name = "info",
            required = false,
            example = ""
    )
    private String info;
    @ApiModelProperty(
            value = "绑定状态（0未绑定，1已绑定）",
            name = "bindStatus",
            required = false,
            example = ""
    )
    private Boolean bindStatus;
    @ApiModelProperty(
            value = "有效期开始时间",
            name = "validDateStart",
            required = false,
            example = ""
    )
    private Date validDateStart;
    @ApiModelProperty(
            value = "有效期结束时间",
            name = "validDateEnd",
            required = false,
            example = ""
    )
    private Date validDateEnd;
    @ApiModelProperty(
            value = "是否锁定(0-未锁定 1-锁定)",
            name = "isLock",
            required = false,
            example = ""
    )
    private Boolean isLock;
    @ApiModelProperty(
            value = "核销密码",
            name = "usePassword",
            required = false,
            example = ""
    )
    private String usePassword;
    @ApiModelProperty(
            value = "发放类型（10-开卡发券，15-生日发券，20-受赠，25-积分兑换，30-线上开卡，35-会员升级，40-会员生日，45-会员消费，50-会员签到，55-领券，60-完善资料，65-微信分享，70-消费次数，75-消费金额，80-邀请开卡,85-批量发券）",
            name = "sendType",
            required = false,
            example = ""
    )
    private String sendType;
    @ApiModelProperty(
            value = "发券业务单号(手工发券id)",
            name = "sendBusinessId",
            required = false,
            example = ""
    )
    private Long sendBusinessId;
    @ApiModelProperty(
            value = "使用类型：1-线上，2-线下",
            name = "useType",
            required = false,
            example = ""
    )
    private Byte useType;
    @ApiModelProperty(
            value = "核销门店",
            name = "useStoreId",
            required = false,
            example = ""
    )
    private Long useStoreId;
    @ApiModelProperty(
            value = "券使用业务单号",
            name = "useBusinessCode",
            required = false,
            example = ""
    )
    private String useBusinessCode;
    @ApiModelProperty(
            value = "券使用订单金额(券收益)",
            name = "useBusinessAmount",
            required = false,
            example = "88.88"
    )
    private Long useBusinessAmount;
    @ApiModelProperty(
            value = "使用时间",
            name = "useTime",
            required = false,
            example = ""
    )
    private Date useTime;
    @ApiModelProperty(
            value = "是否使用(1-已使用，0-未使用)",
            name = "isUse",
            required = false,
            example = ""
    )
    private Boolean isUse;
    @ApiModelProperty(
            value = "5-线上绑定，10-同步中，11-同步失败，12-同步成功，20-未使用，25-已过期，30-已核销",
            name = "couponStatus",
            required = false,
            example = ""
    )
    private Byte couponStatus;
    @ApiModelProperty(
            value = "条形码url",
            name = "barcodeUrl",
            required = false,
            example = ""
    )
    private String barcodeUrl;
    @ApiModelProperty(
            value = "备注",
            name = "remark",
            required = false,
            example = ""
    )
    private String remark;
    @ApiModelProperty(
            value = "创建人id",
            name = "createUserId",
            required = false,
            example = ""
    )
    private Long createUserId;
    @ApiModelProperty(
            value = "创建人",
            name = "createUserName",
            required = false,
            example = ""
    )
    private String createUserName;
    @ApiModelProperty(
            value = "创建时间",
            name = "createDate",
            required = false,
            example = ""
    )
    private Date createDate;
    @ApiModelProperty(
            value = "修改人id",
            name = "modifiedUserId",
            required = false,
            example = ""
    )
    private Long modifiedUserId;
    @ApiModelProperty(
            value = "修改人",
            name = "modifiedUserName",
            required = false,
            example = ""
    )
    private String modifiedUserName;
    @ApiModelProperty(
            value = "修改时间",
            name = "modifiedDate",
            required = false,
            example = ""
    )
    private Date modifiedDate;
    @ApiModelProperty(
            value = "数据有效性（1有效，0无效）",
            name = "valid",
            required = false,
            example = ""
    )
    private Boolean valid;
    @ApiModelProperty(
            value = "优惠类型（1现金，2折扣，3礼品）",
            name = "preferentialType",
            required = false,
            example = ""
    )
    private Byte preferentialType;
    @ApiModelProperty(
            value = "转赠状态 (0-未转赠，1-转赠中)",
            name = "give",
            required = false,
            example = ""
    )
    private Boolean give;
    private String oldMemberCode;
    private static final long serialVersionUID = 1L;
    private String wxHeadPortraits;
    private String wxNick;
    private String receiveTime;
    //领取状态0是未领取1是已领取
    private Integer receiveState;

    public Integer getReceiveState() {
        return receiveState;
    }

    public void setReceiveState(Integer receiveState) {
        this.receiveState = receiveState;
    }

    public String getWxHeadPortraits() {
        return wxHeadPortraits;
    }

    public void setWxHeadPortraits(String wxHeadPortraits) {
        this.wxHeadPortraits = wxHeadPortraits;
    }

    public String getWxNick() {
        return wxNick;
    }

    public void setWxNick(String wxNick) {
        this.wxNick = wxNick;
    }

    public String getReceiveTime() {
        return receiveTime;
    }

    public void setReceiveTime(String receiveTime) {
        this.receiveTime = receiveTime;
    }

    public String getOldMemberCode() {
        return oldMemberCode;
    }

    public void setOldMemberCode(String oldMemberCode) {
        this.oldMemberCode = oldMemberCode;
    }

    public Long getCouponEntityId() {
        return couponEntityId;
    }

    public void setCouponEntityId(Long couponEntityId) {
        this.couponEntityId = couponEntityId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(String couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public Long getCouponBatchSendRecordId() {
        return couponBatchSendRecordId;
    }

    public void setCouponBatchSendRecordId(Long couponBatchSendRecordId) {
        this.couponBatchSendRecordId = couponBatchSendRecordId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public String getImg() {
        return img;
    }

    public void setImg(String img) {
        this.img = img;
    }

    public String getInfo() {
        return info;
    }

    public void setInfo(String info) {
        this.info = info;
    }

    public Boolean getBindStatus() {
        return bindStatus;
    }

    public void setBindStatus(Boolean bindStatus) {
        this.bindStatus = bindStatus;
    }

    public Date getValidDateStart() {
        return validDateStart;
    }

    public void setValidDateStart(Date validDateStart) {
        this.validDateStart = validDateStart;
    }

    public Date getValidDateEnd() {
        return validDateEnd;
    }

    public void setValidDateEnd(Date validDateEnd) {
        this.validDateEnd = validDateEnd;
    }

    public Boolean getLock() {
        return isLock;
    }

    public void setLock(Boolean lock) {
        isLock = lock;
    }

    public String getUsePassword() {
        return usePassword;
    }

    public void setUsePassword(String usePassword) {
        this.usePassword = usePassword;
    }

    public String getSendType() {
        return sendType;
    }

    public void setSendType(String sendType) {
        this.sendType = sendType;
    }

    public Long getSendBusinessId() {
        return sendBusinessId;
    }

    public void setSendBusinessId(Long sendBusinessId) {
        this.sendBusinessId = sendBusinessId;
    }

    public Byte getUseType() {
        return useType;
    }

    public void setUseType(Byte useType) {
        this.useType = useType;
    }

    public Long getUseStoreId() {
        return useStoreId;
    }

    public void setUseStoreId(Long useStoreId) {
        this.useStoreId = useStoreId;
    }

    public String getUseBusinessCode() {
        return useBusinessCode;
    }

    public void setUseBusinessCode(String useBusinessCode) {
        this.useBusinessCode = useBusinessCode;
    }

    public Long getUseBusinessAmount() {
        return useBusinessAmount;
    }

    public void setUseBusinessAmount(Long useBusinessAmount) {
        this.useBusinessAmount = useBusinessAmount;
    }

    public Date getUseTime() {
        return useTime;
    }

    public void setUseTime(Date useTime) {
        this.useTime = useTime;
    }

    public Boolean getUse() {
        return isUse;
    }

    public void setUse(Boolean use) {
        isUse = use;
    }

    public Byte getCouponStatus() {
        return couponStatus;
    }

    public void setCouponStatus(Byte couponStatus) {
        this.couponStatus = couponStatus;
    }

    public String getBarcodeUrl() {
        return barcodeUrl;
    }

    public void setBarcodeUrl(String barcodeUrl) {
        this.barcodeUrl = barcodeUrl;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName;
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public Byte getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(Byte preferentialType) {
        this.preferentialType = preferentialType;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Boolean getGive() {
        return give;
    }

    public void setGive(Boolean give) {
        this.give = give;
    }
}

==> applet-service-2.0.7-20220721.105045-2-sources.jar: com/bizvane/appletservice/models/bo/CouponDetailResponseBo.java <==
package com.bizvane.appletservice.models.bo;

import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.Date;

public class CouponDetailResponseBo {
    @ApiModelProperty(
            value = "pkid",
            name = "couponEntityId",
            required = false,
            example = ""
    )
    private Long couponEntityId;
    @ApiModelProperty(
            value = "所属企业id",
            name = "sysCompanyId",
            required = false,
            example = ""
    )
    private Long sysCompanyId;
    @ApiModelProperty(
            value = "所属品牌id",
            name = "sysBrandId",
            required = false,
            example = ""
    )
    private Long sysBrandId;
    @ApiModelProperty(
            value = "所属品牌编号",
            name = "brandCode",
            required = false,
            example = ""
    )
    private String brandCode;
    @ApiModelProperty(
            value = "券号",
            name = "couponCode",
            required = false,
            example = ""
    )
    private String couponCode;
    @ApiModelProperty(
            value = "券定义id",
            name = "couponDefinitionId",
            required = false,
            example = ""
    )
    private String couponDefinitionId;
    @ApiModelProperty(
            value = "券发送记录id",
            name = "couponBatchSendRecordId",
            required = false,
            example = ""
    )
    private Long couponBatchSendRecordId;
    @ApiModelProperty(
            value = "会员code",
            name = "memberCode",
            required = false,
            example = ""
    )
    private String memberCode;
    @ApiModelProperty(
            value = "券名称",
            name = "couponName",
            required = false,
            example = ""
    )
    private String couponName;
    @ApiModelProperty(
            value = "面额",
            name = "money",
            required = false,
            example = ""
    )
    private BigDecimal money;
    @ApiModelProperty(
            value = "折扣",
            name = "discount",
            required = false,
            example = ""
    )
    private BigDecimal discount;
    @ApiModelProperty(
            value = "券模板图片",
            name = "img",
            required = false,
            example = ""
    )
    private String img;
    @ApiModelProperty(
            value = "券说明",
            name = "info",
            required = false,
            example = ""
    )
    private String info;
    @ApiModelProperty(
            value = "绑定状态（0未绑定，1已绑定）",
            name = "bindStatus",
            required = false,
            example = ""
    )
    private Boolean bindStatus;
    @ApiModelProperty(
            value = "有效期开始时间",
            name = "validDateStart",
            required = false,
            example = ""
    )
    private Date validDateStart;
    @ApiModelProperty(
            value = "有效期结束时间",
            name = "validDateEnd",
            required = false,
            example = ""
    )
    private Date validDateEnd;
    @ApiModelProperty(
            value = "是否锁定(0-未锁定 1-锁定)",
            name = "isLock",
            required = false,
            example = ""
    )
    private Boolean isLock;
    @ApiModelProperty(
            value = "核销密码",
            name = "usePassword",
            required = false,
            example = ""
    )
    private String usePassword;
    @ApiModelProperty(
            value = "发放类型（10-开卡发券，15-生日发券，20-受赠，25-积分兑换，30-线上开卡，35-会员升级，40-会员生日，45-会员消费，50-会员签到，55-领券，60-完善资料，65-微信分享，70-消费次数，75-消费金额，80-邀请开卡,85-批量发券）",
            name = "sendType",
            required = false,
            example = ""
    )
    private String sendType;
    @ApiModelProperty(
            value = "发券业务单号(手工发券id)",
            name = "sendBusinessId",
            required = false,
            example = ""
    )
    private Long sendBusinessId;
    @ApiModelProperty(
            value = "使用类型：1-线上，2-线下",
            name = "useType",
            required = false,
            example = ""
    )
    private Byte useType;
    @ApiModelProperty(
            value = "核销门店",
            name = "useStoreId",
            required = false,
            example = ""
    )
    private Long useStoreId;
    @ApiModelProperty(
            value = "券使用业务单号",
            name = "useBusinessCode",
            required = false,
            example = ""
    )
    private String useBusinessCode;
    @ApiModelProperty(
            value = "券使用订单金额(券收益)",
            name = "useBusinessAmount",
            required = false,
            example = "88.88"
    )
    private Long useBusinessAmount;
    @ApiModelProperty(
            value = "使用时间",
            name = "useTime",
            required = false,
            example = ""
    )
    private Date useTime;
    @ApiModelProperty(
            value = "是否使用(1-已使用，0-未使用)",
            name = "isUse",
            required = false,
            example = ""
    )
    private Boolean isUse;
    @ApiModelProperty(
            value = "5-线上绑定，10-同步中，11-同步失败，12-同步成功，20-未使用，25-已过期，30-已核销",
            name = "couponStatus",
            required = false,
            example = ""
    )
    private Byte couponStatus;
    @ApiModelProperty(
            value = "条形码url",
            name = "barcodeUrl",
            required = false,
            example = ""
    )
    private String barcodeUrl;
    @ApiModelProperty(
            value = "备注",
            name = "remark",
            required = false,
            example = ""
    )
    private String remark;
    @ApiModelProperty(
            value = "创建人id",
            name = "createUserId",
            required = false,
            example = ""
    )
    private Long createUserId;
    @ApiModelProperty(
            value = "创建人",
            name = "createUserName",
            required = false,
            example = ""
    )
    private String createUserName;
    @ApiModelProperty(
            value = "创建时间",
            name = "createDate",
            required = false,
            example = ""
    )
    private Date createDate;
    @ApiModelProperty(
            value = "修改人id",
            name = "modifiedUserId",
            required = false,
            example = ""
    )
    private Long modifiedUserId;
    @ApiModelProperty(
            value = "修改人",
            name = "modifiedUserName",
            required = false,
            example = ""
    )
    private String modifiedUserName;
    @ApiModelProperty(
            value = "修改时间",
            name = "modifiedDate",
            required = false,
            example = ""
    )
    private Date modifiedDate;
    @ApiModelProperty(
            value = "数据有效性（1有效，0无效）",
            name = "valid",
            required = false,
            example = ""
    )
    private Boolean valid;
    @ApiModelProperty(
            value = "优惠类型（1现金，2折扣，3礼品）",
            name = "preferentialType",
            required = false,
            example = ""
    )
    private Byte preferentialType;
    @ApiModelProperty(
            value = "转赠状态 (0-未转赠，1-转赠中)",
            name = "give",
            required = false,
            example = ""
    )
    private Boolean give;
    private String oldMemberCode;
    private static final long serialVersionUID = 1L;
    private String wxHeadPortraits;
    private String wxNick;
    private String receiveTime;
    //领取状态0是未领取1是已领取
    private Integer receiveState;

    private Boolean isBack;

    public Boolean getBack() {
        return isBack;
    }

    public void setBack(Boolean back) {
        isBack = back;
    }

    public Integer getReceiveState() {
        return receiveState;
    }

    public void setReceiveState(Integer receiveState) {
        this.receiveState = receiveState;
    }

    public String getWxHeadPortraits() {
        return wxHeadPortraits;
    }

    public void setWxHeadPortraits(String wxHeadPortraits) {
        this.wxHeadPortraits = wxHeadPortraits;
    }

    public String getWxNick() {
        return wxNick;
    }

    public void setWxNick(String wxNick) {
        this.wxNick = wxNick;
    }

    public String getReceiveTime() {
        return receiveTime;
    }

    public void setReceiveTime(String receiveTime) {
        this.receiveTime = receiveTime;
    }

    public String getOldMemberCode() {
        return oldMemberCode;
    }

    public void setOldMemberCode(String oldMemberCode) {
        this.oldMemberCode = oldMemberCode;
    }

    public Long getCouponEntityId() {
        return couponEntityId;
    }

    public void setCouponEntityId(Long couponEntityId) {
        this.couponEntityId = couponEntityId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(String couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public Long getCouponBatchSendRecordId() {
        return couponBatchSendRecordId;
    }

    public void setCouponBatchSendRecordId(Long couponBatchSendRecordId) {
        this.couponBatchSendRecordId = couponBatchSendRecordId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public String getImg() {
        return img;
    }

    public void setImg(String img) {
        this.img = img;
    }

    public String getInfo() {
        return info;
    }

    public void setInfo(String info) {
        this.info = info;
    }

    public Boolean getBindStatus() {
        return bindStatus;
    }

    public void setBindStatus(Boolean bindStatus) {
        this.bindStatus = bindStatus;
    }

    public Date getValidDateStart() {
        return validDateStart;
    }

    public void setValidDateStart(Date validDateStart) {
        this.validDateStart = validDateStart;
    }

    public Date getValidDateEnd() {
        return validDateEnd;
    }

    public void setValidDateEnd(Date validDateEnd) {
        this.validDateEnd = validDateEnd;
    }

    public Boolean getLock() {
        return isLock;
    }

    public void setLock(Boolean lock) {
        isLock = lock;
    }

    public String getUsePassword() {
        return usePassword;
    }

    public void setUsePassword(String usePassword) {
        this.usePassword = usePassword;
    }

    public String getSendType() {
        return sendType;
    }

    public void setSendType(String sendType) {
        this.sendType = sendType;
    }

    public Long getSendBusinessId() {
        return sendBusinessId;
    }

    public void setSendBusinessId(Long sendBusinessId) {
        this.sendBusinessId = sendBusinessId;
    }

    public Byte getUseType() {
        return useType;
    }

    public void setUseType(Byte useType) {
        this.useType = useType;
    }

    public Long getUseStoreId() {
        return useStoreId;
    }

    public void setUseStoreId(Long useStoreId) {
        this.useStoreId = useStoreId;
    }

    public String getUseBusinessCode() {
        return useBusinessCode;
    }

    public void setUseBusinessCode(String useBusinessCode) {
        this.useBusinessCode = useBusinessCode;
    }

    public Long getUseBusinessAmount() {
        return useBusinessAmount;
    }

    public void setUseBusinessAmount(Long useBusinessAmount) {
        this.useBusinessAmount = useBusinessAmount;
    }

    public Date getUseTime() {
        return useTime;
    }

    public void setUseTime(Date useTime) {
        this.useTime = useTime;
    }

    public Boolean getUse() {
        return isUse;
    }

    public void setUse(Boolean use) {
        isUse = use;
    }

    public Byte getCouponStatus() {
        return couponStatus;
    }

    public void setCouponStatus(Byte couponStatus) {
        this.couponStatus = couponStatus;
    }

    public String getBarcodeUrl() {
        return barcodeUrl;
    }

    public void setBarcodeUrl(String barcodeUrl) {
        this.barcodeUrl = barcodeUrl;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName;
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public Byte getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(Byte preferentialType) {
        this.preferentialType = preferentialType;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Boolean getGive() {
        return give;
    }

    public void setGive(Boolean give) {
        this.give = give;
    }
}
